@@ -1,4 +1,4 @@
-# Copyright 2020 Ankur Gupta
+# Copyright 2020 Flicker Contributors
 #
 #    Licensed under the Apache License, Version 2.0 (the "License");
 #    you may not use this file except in compliance with the License.
@@ -16,4 +16,5 @@
 import os
 
 from flicker.version import __version__
-from flicker.flicker import FlickerDataFrame
+from flicker.dataframe import FlickerDataFrame
+from flicker.group import FlickerGroupedData
